pygeodesy.fstats._FstatsBase

Package pygeodesy :: Module fstats :: Class _FstatsBase |
[frames] | no frames]

# Class _FstatsBase

      object --+
               |
    named._Named --+
                   |
        _FstatsNamed --+
                       |
                      _FstatsBase

Known Subclasses:
  - Fcook
  - , Fwelford

(INTERNAL) Base running stats class.

Instance Methods
fadd(self, xs, sample=False) Must be overloaded. |
fadd_(self, *xs, **sample) Accumulate and return the current count. |
fmean(self, xs=None) Accumulate and return the current mean. |
fmean_(self, *xs) Accumulate and return the current mean. |
fstdev(self, xs=None, **sample) Accumulate and return the current standard deviation. |
fstdev_(self, *xs, **sample) Accumulate and return the current standard deviation. |
fvariance(self, xs=None, **sample) Accumulate and return the current variance. |
fvariance_(self, *xs, **sample) Accumulate and return the current variance. |
Inherited from `_FstatsNamed`: `__add__`, `__float__`, `__int__`, `__len__`, `__neg__`, `__radd__`, `__str__`, `copy`, `fcopy` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `attrs`, `classof`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### fadd_ (self, *xs, **sample) |
Accumulate and return the current count. See Also: Method `fadd` for further details.

### fmean (self, xs=None) |
Accumulate and return the current mean. Arguments: `xs` - Iterable of additional values (each `scalar`, an Fsum or Fsum2Tuple). Returns: Current, running mean (`float`). See Also: Method `fadd`.

### fmean_ (self, *xs) |
Accumulate and return the current mean. See Also: Method `fmean` for further details.

### fstdev (self, xs=None, **sample) |
Accumulate and return the current standard deviation. Arguments: `xs` - Iterable of additional values (each `scalar`, an Fsum or Fsum2Tuple). `sample` - Use `sample=True` for the sample deviation instead of the population deviation (`bool`). Returns: Current, running (sample) standard deviation (`float`). See Also: Method `fadd`.

### fstdev_ (self, *xs, **sample) |
Accumulate and return the current standard deviation. See Also: Method `fstdev` for further details.

### fvariance (self, xs=None, **sample) |
Accumulate and return the current variance. Arguments: `xs` - Iterable of additional values (each `scalar`, an Fsum or Fsum2Tuple). `sample` - Use `sample=True` for the sample variance instead of the population variance (`bool`). Returns: Current, running (sample) variance (`float`). See Also: Method `fadd`.

### fvariance_ (self, *xs, **sample) |
Accumulate and return the current variance. See Also: Method `fvariance` for further details.